"""
URL configuration for TimeDispatcher project.

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/5.1/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.urls import path, register_converter, re_path
from django.views.static import serve

from TimeDispatcher import settings
from TimeDispatcher.converters import DateConverter, YearMonthConverter
from dispatcher import views

register_converter(DateConverter, "date")
register_converter(YearMonthConverter, "year_month")

urlpatterns = [
    path("", views.dashboard_view, name="dashboard"),
    path("import/", views.import_view, name="import"),
    path("projects/", views.ProjectsView.as_view(), name="projects"),
    path("parents/", views.ParentsView.as_view(), name="parents"),
    path("table/<date:start_date>/<date:end_date>/", views.get_table_data, name="table_data"),
    path("table/", views.table_view, name="table"),
    path("parents/new/", views.new_parent_view, name="new_parent"),
    path("parents/<int:id>/on_delete/", views.parent_on_delete_view, name="parent_on_delete"),
    path("parents/<int:id>/", views.parent_view, name="parent"),
    path("projects/new/", views.new_project_view, name="new_project"),
    path("projects/<int:id>/on_delete/", views.project_on_delete_view, name="project_on_delete"),
    path("projects/<int:id>/set_parent/", views.set_parent, name="set_parent"),
    path("projects/<int:id>/", views.project_view, name="project"),
    path("stats/by-month/<int:year>/<int:month>/", views.get_stats_by_month, name="stats_by_month"),
    path("clockings/<date:date>/", views.set_clocking, name="set_clocking"),
    path("sagex/<int:id>/<year_month:month>/", views.set_real_sagex, name="set_real_sagex"),
]

if not settings.DEBUG:
    urlpatterns.append(re_path(r"^static/(?P<path>.*)$", serve, {"document_root": settings._STATIC_ROOT}))